==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/coretelephony/CTCallCenter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.coretelephony;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 4.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("CoreTelephony") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/CTCallCenter/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class CTCallCenterPtr extends Ptr<CTCallCenter, CTCallCenterPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(CTCallCenter.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public CTCallCenter() {}
    protected CTCallCenter(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    /**
     * @since Available in iOS 4.0 and later.
     */
    @Property(selector = "currentCalls")
    public native NSSet<CTCall> getCurrentCalls();
    /**
     * @since Available in iOS 4.0 and later.
     */
    @Property(selector = "callEventHandler")
    public native @Block VoidBlock1<CTCall> getCallEventHandler();
    /**
     * @since Available in iOS 4.0 and later.
     */
    @Property(selector = "setCallEventHandler:")
    public native void setCallEventHandler(@Block VoidBlock1<CTCall> v);
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/coretelephony/CTCallCenter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.coretelephony;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @deprecated Deprecated in iOS 10.0. Replaced by CXCallObserver from CallKit.framework
 */
/*</javadoc>*/
/*<annotations>*/@Library("CoreTelephony") @NativeClass @Deprecated/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/CTCallCenter/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class CTCallCenterPtr extends Ptr<CTCallCenter, CTCallCenterPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(CTCallCenter.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public CTCallCenter() {}
    protected CTCallCenter(Handle h, long handle) { super(h, handle); }
    protected CTCallCenter(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    /**
     * @deprecated Deprecated in iOS 10.0. Replaced by <CallKit/CXCallObserver.h>
     */
    @Deprecated
    @Property(selector = "currentCalls")
    public native NSSet<CTCall> getCurrentCalls();
    /**
     * @deprecated Deprecated in iOS 10.0. Replaced by <CallKit/CXCallObserver.h>
     */
    @Deprecated
    @Property(selector = "callEventHandler")
    public native @Block VoidBlock1<CTCall> getCallEventHandler();
    /**
     * @deprecated Deprecated in iOS 10.0. Replaced by <CallKit/CXCallObserver.h>
     */
    @Deprecated
    @Property(selector = "setCallEventHandler:")
    public native void setCallEventHandler(@Block VoidBlock1<CTCall> v);
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    
    /*</methods>*/
}
